"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServiceConnector = void 0;
const oauth_connector_1 = require("@fusebit-int/oauth-connector");
const Service_1 = require("./Service");
const TOKEN_URL = 'https://gitlab.com/oauth/token';
const AUTHORIZATION_URL = 'https://gitlab.com/oauth/authorize';
const REVOCATION_URL = 'https://gitlab.com/oauth/revoke';
const SERVICE_NAME = 'GitLab';
const CONFIGURATION_SECTION = 'Fusebit Connector Configuration';
class ServiceConnector extends oauth_connector_1.OAuthConnector {
    constructor() {
        super();
        this.router.get('/api/configure', async (ctx) => {
            // Adjust the configuration elements here
            ctx.body.uischema.elements.find((element) => element.label == 'OAuth2 Configuration').label =
                'GitLab Configuration';
            this.addConfigurationElement(ctx, CONFIGURATION_SECTION, 'webhookSecret');
            // Adjust the data schema
            ctx.body.schema.properties.scope.description = 'Space separated scopes to request from your GitLab App';
            ctx.body.schema.properties.clientId.description = 'The Client ID from your GitLab App';
            ctx.body.schema.properties.clientSecret.description = 'The Client Secret from your GitLab App';
            ctx.body.schema.properties.webhookSecret = {
                title: 'Webhook Secret from your GitLab App',
                type: 'string',
            };
        });
    }
    createService() {
        return new ServiceConnector.Service();
    }
    addUrlConfigurationAdjustment() {
        return this.adjustUrlConfiguration(TOKEN_URL, AUTHORIZATION_URL, SERVICE_NAME.toLowerCase());
    }
}
exports.ServiceConnector = ServiceConnector;
ServiceConnector.Service = Service_1.Service;
const connector = new ServiceConnector();
exports.default = connector;
//# sourceMappingURL=index.js.map